@@ -3,7 +3,7 @@ package Bundle::WWW::Scraper::ISBN::Drivers;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "1.02";
+$VERSION = "1.03";
 
 1;
 
@@ -41,8 +41,12 @@ WWW::Scraper::ISBN::AmazonUK_Driver
 
 WWW::Scraper::ISBN::AmazonUS_Driver
 
+WWW::Scraper::ISBN::BookDepository_Driver
+
 WWW::Scraper::ISBN::Booktopia_Driver
 
+WWW::Scraper::ISBN::EmporiumBooks_Driver
+
 WWW::Scraper::ISBN::ISBNdb_Driver
 
 WWW::Scraper::ISBN::ISBNnu_Driver
